Method: TableRowComponent#render

Defined in:
lib/html-native/collections.rb

#renderObject

Converts the TableRowComponent instance to the equivalent HTML.

render can be called directly, but that usually isn’t necessary. HTMLComponent::Builder handles this automatically, so it only needs to be done if there is no prior instance of one.



231
232
233
234
235
236
237
# File 'lib/html-native/collections.rb', line 231

def render
  tr(@row_attributes) do
    @data.component_map do |c|
      td(@cell_attributes) {@block ? @block.call(c) : c}
    end
  end
end